bayespy.nodes.SwitchingGaussianMarkovChain.plates_multiplier
============================================================

.. currentmodule:: bayespy.nodes

.. autoattribute:: SwitchingGaussianMarkovChain.plates_multiplier